==> ejc-sddjsorg-impl-3.0.0-20211019.091636-32-sources.jar: com/ejianc/business/production/bean/ConformanceContentEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-合规性目录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_conformance_content")
public class ConformanceContentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="name")
    private java.lang.String name; // 档案资料名称
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="enclosure_memo")
    private java.lang.String enclosureMemo; // 附件说明
    
    
    

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 附件说明
     */
    public java.lang.String getEnclosureMemo() {
        return enclosureMemo;
    }

    /**
     * 附件说明
     */
    public void setEnclosureMemo(java.lang.String enclosureMemo) {
        this.enclosureMemo = enclosureMemo;
    }
    
}

==> ejc-sddjsorg-impl-3.0.0-20211104.063347-142-sources.jar: com/ejianc/business/production/bean/ConformanceContentEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-合规性目录
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_conformance_content")
public class ConformanceContentEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 档案资料id
     */
    @TableField(value="file_set_id")
    private Long fileSetId;
    @TableField(value="name")
    private java.lang.String name; // 档案资料名称
    @TableField(value="required")
    private Boolean required; // 是否必须上传
    @TableField(value="memo")
    private java.lang.String memo; // 备注
    @TableField(value="enclosure_memo")
    private java.lang.String enclosureMemo; // 附件说明
    @TableField(value="pid")
    private Long pid;
    /**
     * 附件Ids,多个逗号分隔 依此判断是否上传
     */
    @TableField(value="file_ids")
    private String fileIds;

    public String getFileIds() {
        return fileIds;
    }

    public void setFileIds(String fileIds) {
        this.fileIds = fileIds;
    }

    public Long getFileSetId() {
        return fileSetId;
    }

    public void setFileSetId(Long fileSetId) {
        this.fileSetId = fileSetId;
    }

    public Boolean getRequired() {
        return required;
    }

    public void setRequired(Boolean required) {
        this.required = required;
    }

    /**
     * 档案资料名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 档案资料名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 备注
     */
    public java.lang.String getMemo() {
        return memo;
    }

    /**
     * 备注
     */
    public void setMemo(java.lang.String memo) {
        this.memo = memo;
    }
    /**
     * 附件说明
     */
    public java.lang.String getEnclosureMemo() {
        return enclosureMemo;
    }

    /**
     * 附件说明
     */
    public void setEnclosureMemo(java.lang.String enclosureMemo) {
        this.enclosureMemo = enclosureMemo;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
}
